@@ -1,53 +1,48 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="cs">
+<TS version="2.1" language="cs" sourcelanguage="en">
 <context>
     <name>AddImage</name>
     <message>
-        <location filename="../src/add_image.cpp" line="87"/>
         <source>Open Image</source>
         <translation>Otevřít obrázek</translation>
     </message>
+    <message>
+        <source>Images</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AppearanceDialog</name>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="59"/>
         <source>Appearance</source>
         <translation>Vzhled</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="68"/>
         <source>Options</source>
         <translation>Možnosti</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="70"/>
         <source>Beveled borders</source>
         <translation>Zkosené okraje</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="73"/>
         <source>Drop shadows</source>
         <translation>Stíny</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="77"/>
         <source>Colors</source>
         <translation>Barvy</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="96"/>
         <source>Background:</source>
         <translation>Pozadí:</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="97"/>
         <source>Shadow:</source>
         <translation>Stín:</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="98"/>
         <source>Highlight:</source>
         <translation>Zvýraznění:</translation>
     </message>
@@ -55,59 +50,42 @@
 <context>
     <name>Board</name>
     <message>
-        <location filename="../src/board.cpp" line="187"/>
-        <location filename="../src/board.cpp" line="293"/>
-        <location filename="../src/board.cpp" line="361"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="187"/>
-        <location filename="../src/board.cpp" line="293"/>
         <source>Missing image.</source>
         <translation>Chybějící obrázek.</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="194"/>
-        <location filename="../src/board.cpp" line="269"/>
-        <location filename="../src/main.cpp" line="167"/>
         <source>Please Wait</source>
         <translation>Prosím čekejte</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="216"/>
-        <location filename="../src/board.cpp" line="368"/>
         <source>Loading image...</source>
         <translation>Nahrávání obrázku…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="222"/>
         <source>Generating puzzle...</source>
         <translation>Vytváření skládanky…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="228"/>
-        <location filename="../src/board.cpp" line="242"/>
         <source>Creating pieces...</source>
         <translation>Vytváření dílů…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="281"/>
         <source>Loading puzzle...</source>
         <translation>Nahrávání skládanky…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="306"/>
         <source>Unknown data format</source>
         <translation>Neznámý formát dat</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="356"/>
         <source>Unknown element &apos;%1&apos;</source>
         <translation>Neznámý prvek „%1“</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="361"/>
         <source>Error parsing XML file.
 
 %1</source>
@@ -116,22 +94,18 @@
 %1</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="372"/>
         <source>Loading pieces...</source>
         <translation>Nahrávání dílů…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="454"/>
         <source>Retrieving pieces...</source>
         <translation>Shromažďování dílů…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="994"/>
         <source>Placing pieces...</source>
         <translation>Rozmisťování dílů…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="1326"/>
         <source>Success</source>
         <translation>Úspěch</translation>
     </message>
@@ -139,58 +113,56 @@
 <context>
     <name>ChooseGameDialog</name>
     <message>
-        <location filename="../src/choose_game_dialog.cpp" line="38"/>
         <source>Choose Game</source>
         <translation>Vybrat hru</translation>
     </message>
     <message>
-        <location filename="../src/choose_game_dialog.cpp" line="52"/>
         <source>Current Games</source>
         <translation>Rozehrané hry</translation>
     </message>
     <message>
-        <location filename="../src/choose_game_dialog.cpp" line="57"/>
         <source>New Game</source>
         <translation>Nová hra</translation>
     </message>
+    <message>
+        <source>Play Game</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImagePropertiesDialog</name>
     <message>
-        <location filename="../src/image_properties_dialog.cpp" line="39"/>
         <source>Image Properties</source>
         <translation>Vlastnosti obrázku</translation>
     </message>
     <message>
-        <location filename="../src/image_properties_dialog.cpp" line="72"/>
         <source>Name:</source>
         <translation>jméno:</translation>
     </message>
     <message>
-        <location filename="../src/image_properties_dialog.cpp" line="73"/>
         <source>Tags:</source>
         <translation>Štítky:</translation>
     </message>
+    <message>
+        <source>New tag name</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="50"/>
         <source>Select application language:</source>
         <translation>Vyberte jazyk aplikace:</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="53"/>
         <source>&lt;System Language&gt;</source>
         <translation>Systémový jazyk</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="183"/>
         <source>Note</source>
         <translation>Poznámka</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="183"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Pro uplatnění změn v nastavení jazyka prosím ukončete a znovu spusťte aplikaci.</translation>
     </message>
@@ -198,81 +170,73 @@
 <context>
     <name>NewGameTab</name>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="105"/>
         <source>Add Image</source>
         <translation>Přidat obrázek</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="109"/>
-        <location filename="../src/new_game_tab.cpp" line="290"/>
         <source>Remove Image</source>
         <translation>Odstranit obrázek</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="113"/>
         <source>Image Properties</source>
         <translation>Vlastnosti obrázku</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="132"/>
-        <location filename="../src/new_game_tab.cpp" line="383"/>
         <source>%L1 pieces</source>
         <translation>%L1 dílů</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="193"/>
         <source>Copying images...</source>
         <translation>Kopírování obrázků…</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="193"/>
         <source>Cancel</source>
         <translation>Zrušit</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="286"/>
-        <source>Remove selected image?</source>
-        <translation>Odstranit vybraný obrázek?</translation>
-    </message>
-    <message>
-        <location filename="../src/new_game_tab.cpp" line="288"/>
-        <source>Remove selected image?
-
-There are saved games using this image that will also be removed.</source>
-        <translation>Odstranit vybraný obrázek?
-
-Některé z rozehraných her používají tento obrázek, odstraníte-li jej, budou taktéž odstraněny.</translation>
-    </message>
-    <message>
-        <location filename="../src/new_game_tab.cpp" line="493"/>
         <source>Untitled</source>
         <translation>Nepojmenovaný</translation>
     </message>
+    <message numerus="yes">
+        <source>Remove %n selected image(s)?</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Saved games using these image(s) will be deleted.</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>OpenGameTab</name>
     <message>
-        <location filename="../src/open_game_tab.cpp" line="86"/>
         <source>Untitled</source>
         <translation>Nepojmenovaný</translation>
     </message>
     <message>
-        <location filename="../src/open_game_tab.cpp" line="89"/>
         <source>%L1 pieces %2 %3% complete</source>
         <translation>%L1 dílů %2 %3% dokončeno</translation>
     </message>
     <message>
-        <location filename="../src/open_game_tab.cpp" line="105"/>
         <source>Delete</source>
         <translation>Smazat</translation>
     </message>
     <message>
-        <location filename="../src/open_game_tab.cpp" line="148"/>
         <source>Delete Game</source>
         <translation>Smazat hru</translation>
     </message>
     <message>
-        <location filename="../src/open_game_tab.cpp" line="148"/>
         <source>Delete selected game?</source>
         <translation>Smazat vybranou hru?</translation>
     </message>
@@ -280,7 +244,6 @@ Některé z rozehraných her používají tento obrázek, odstraníte-li jej, bu
 <context>
     <name>Overview</name>
     <message>
-        <location filename="../src/overview.cpp" line="38"/>
         <source>Overview</source>
         <translation>Náhled</translation>
     </message>
@@ -288,278 +251,233 @@ Některé z rozehraných her používají tento obrázek, odstraníte-li jej, bu
 <context>
     <name>TagManager</name>
     <message>
-        <location filename="../src/tag_manager.cpp" line="50"/>
         <source>Add Tag</source>
         <translation>Přidat štítek</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="54"/>
         <source>Remove Tag</source>
         <translation>Odstranit štítek</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="59"/>
         <source>Untagged</source>
         <translation>Bez štítku</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="88"/>
         <source>All Images</source>
         <translation>Všechny obrázky</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="208"/>
         <source>Untitled %1</source>
         <translation>Nepojmenovaný %1</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="232"/>
         <source>Question</source>
         <translation>Otázka</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="232"/>
         <source>Remove selected tag?</source>
         <translation>Odstranit vybrané štítky?</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="273"/>
         <source>Sorry</source>
         <translation>Je nám líto</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="273"/>
         <source>A tag with that name already exists.</source>
         <translation>Štítek s tímto jménem již existuje.</translation>
     </message>
+    <message>
+        <source>Manage Tags...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/main.cpp" line="168"/>
-        <location filename="../src/window.cpp" line="50"/>
-        <location filename="../src/window.cpp" line="286"/>
         <source>Tetzle</source>
         <translation>Tetzle</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="80"/>
         <source>&amp;Game</source>
         <translation>&amp;Hra</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="84"/>
         <source>&amp;Retrieve Pieces</source>
         <translation>&amp;Shromáždit díly</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="84"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="88"/>
         <source>&amp;Quit</source>
         <translation>&amp;Ukončit</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="81"/>
         <source>&amp;Choose...</source>
         <translation>&amp;Vybrat…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="91"/>
         <source>&amp;View</source>
         <translation>&amp;Zobrazit</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="92"/>
         <source>Zoom &amp;In</source>
         <translation>&amp;Přiblížit</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="92"/>
         <source>+</source>
         <translation>+</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="95"/>
         <source>Zoom &amp;Out</source>
         <translation>&amp;Oddálit</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="95"/>
         <source>-</source>
         <translation>-</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="98"/>
         <source>Best &amp;Fit</source>
         <translation>O&amp;ptimální zobrazení</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="101"/>
         <source>Show O&amp;verview</source>
         <translation>&amp;Zobrazit náhled</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="101"/>
         <source>Tab</source>
         <translation>Tab</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="107"/>
         <source>F&amp;ullscreen</source>
         <translation>&amp;Celá obrazovka</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="111"/>
         <source>F11</source>
         <translation>F11</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="113"/>
         <source>Ctrl+F</source>
         <translation>Ctrl+F</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="116"/>
         <source>&amp;Settings</source>
         <translation>&amp;Nastavení</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="117"/>
         <source>&amp;Appearance...</source>
         <translation>&amp;Vzhled…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="118"/>
         <source>&amp;Language...</source>
         <translation>&amp;Jazyk…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="120"/>
         <source>&amp;Help</source>
         <translation>&amp;Nápověda</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="121"/>
         <source>&amp;Controls</source>
         <translation>&amp;Ovládání</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="123"/>
         <source>&amp;About</source>
         <translation>&amp;O aplikaci</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="125"/>
         <source>About &amp;Qt</source>
         <translation>&amp;O Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="252"/>
         <source>Controls</source>
         <translation>Ovládání</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="259"/>
         <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Sebrání dílů:&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="260"/>
-        <location filename="../src/window.cpp" line="262"/>
         <source>Left Click or Space</source>
         <translation>Levé tlačítko nebo mezerník</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="261"/>
         <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Položení dílů:&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="263"/>
         <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Výběr dílů:&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="264"/>
         <source>Left Drag</source>
         <translation>Tažení levým tlačítkem</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="265"/>
         <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Pootočení dílů:&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="266"/>
         <source>Right Click, Control + Left Click, or R</source>
         <translation>Pravé tlačítko, Ctrl + Levé tlačítko, nebo R</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="267"/>
         <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Přetažení skládanky:&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="268"/>
         <source>Middle Click, Shift + Left Click, or Arrows</source>
         <translation>Prostřední tlačítko, Shift + Levé tlačítko, nebo šipky</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="269"/>
         <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Úroveň přiblížení skládanky:&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="270"/>
         <source>Scrollwheel or +/-</source>
         <translation>Kolečko myši nebo +/-</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="271"/>
         <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Pohyb kurzoru:&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="272"/>
         <source>Move mouse or W,A,D,S</source>
         <translation>Myš nebo W, A, D, S</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="285"/>
         <source>About Tetzle</source>
         <translation>O Tetzle</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="287"/>
         <source>A jigsaw puzzle with tetrominoes for pieces</source>
         <translation>Skládanka s díly ve tvaru tetromina</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="288"/>
         <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="289"/>
         <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Vydáno pod licencí &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
     </message>
+    <message>
+        <source>%p% complete</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ZoomSlider</name>
     <message>
-        <location filename="../src/zoom_slider.cpp" line="38"/>
-        <source>??%</source>
-        <translation>??%</translation>
+        <source>Zoom: %1%</source>
+        <translation type="unfinished"></translation>
     </message>
+</context>
+<context>
+    <name>main</name>
     <message>
-        <location filename="../src/zoom_slider.cpp" line="63"/>
-        <source>%1%</source>
-        <translation>%1%</translation>
+        <source>Images to add to the choose game dialog.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
