@@ -1,53 +1,48 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fr">
+<TS version="2.1" language="fr" sourcelanguage="en">
 <context>
     <name>AddImage</name>
     <message>
-        <location filename="../src/add_image.cpp" line="87"/>
         <source>Open Image</source>
         <translation>Ouvrir une image</translation>
     </message>
+    <message>
+        <source>Images</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AppearanceDialog</name>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="59"/>
         <source>Appearance</source>
         <translation>Apparence</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="68"/>
         <source>Options</source>
         <translation>Options</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="70"/>
         <source>Beveled borders</source>
         <translation>Coins biseautés</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="73"/>
         <source>Drop shadows</source>
         <translation>Dissiper les zones d&apos;ombre</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="77"/>
         <source>Colors</source>
         <translation>Couleurs</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="96"/>
         <source>Background:</source>
         <translation>Arrière-plan :</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="97"/>
         <source>Shadow:</source>
         <translation>Ombre :</translation>
     </message>
     <message>
-        <location filename="../src/appearance_dialog.cpp" line="98"/>
         <source>Highlight:</source>
         <translation>Surbrillance :</translation>
     </message>
@@ -55,59 +50,42 @@
 <context>
     <name>Board</name>
     <message>
-        <location filename="../src/board.cpp" line="187"/>
-        <location filename="../src/board.cpp" line="293"/>
-        <location filename="../src/board.cpp" line="361"/>
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="187"/>
-        <location filename="../src/board.cpp" line="293"/>
         <source>Missing image.</source>
         <translation>Image manquante.</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="194"/>
-        <location filename="../src/board.cpp" line="269"/>
-        <location filename="../src/main.cpp" line="146"/>
         <source>Please Wait</source>
         <translation>Veuillez patienter</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="216"/>
-        <location filename="../src/board.cpp" line="368"/>
         <source>Loading image...</source>
         <translation>Chargement de l&apos;image…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="222"/>
         <source>Generating puzzle...</source>
         <translation>Génération du puzzle…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="228"/>
-        <location filename="../src/board.cpp" line="242"/>
         <source>Creating pieces...</source>
         <translation>Création des pièces…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="281"/>
         <source>Loading puzzle...</source>
         <translation>Chargement du puzzle…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="306"/>
         <source>Unknown data format</source>
         <translation>Format de donnée inconnu</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="356"/>
         <source>Unknown element &apos;%1&apos;</source>
         <translation>Élément inconnu &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="361"/>
         <source>Error parsing XML file.
 
 %1</source>
@@ -116,22 +94,18 @@
 %1</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="372"/>
         <source>Loading pieces...</source>
         <translation>Chargement des pièces…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="454"/>
         <source>Retrieving pieces...</source>
         <translation>Pioche des pièces…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="994"/>
         <source>Placing pieces...</source>
         <translation>Disposition des pièces…</translation>
     </message>
     <message>
-        <location filename="../src/board.cpp" line="1326"/>
         <source>Success</source>
         <translation>Succès</translation>
     </message>
@@ -139,58 +113,56 @@
 <context>
     <name>ChooseGameDialog</name>
     <message>
-        <location filename="../src/choose_game_dialog.cpp" line="38"/>
         <source>Choose Game</source>
         <translation>Choisir une partie</translation>
     </message>
     <message>
-        <location filename="../src/choose_game_dialog.cpp" line="52"/>
         <source>Current Games</source>
         <translation>Parties en cours</translation>
     </message>
     <message>
-        <location filename="../src/choose_game_dialog.cpp" line="57"/>
         <source>New Game</source>
         <translation>Nouvelle partie</translation>
     </message>
+    <message>
+        <source>Play Game</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImagePropertiesDialog</name>
     <message>
-        <location filename="../src/image_properties_dialog.cpp" line="39"/>
         <source>Image Properties</source>
         <translation>Propriétés de l&apos;image</translation>
     </message>
     <message>
-        <location filename="../src/image_properties_dialog.cpp" line="72"/>
         <source>Name:</source>
         <translation>Nom :</translation>
     </message>
     <message>
-        <location filename="../src/image_properties_dialog.cpp" line="73"/>
         <source>Tags:</source>
         <translation>Mot-cles :</translation>
     </message>
+    <message>
+        <source>New tag name</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="50"/>
         <source>Select application language:</source>
         <translation>Sélectionner la langue de l&apos;application :</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="53"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Langue du système&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="183"/>
         <source>Note</source>
         <translation>Remarque</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="183"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
     </message>
@@ -198,81 +170,71 @@
 <context>
     <name>NewGameTab</name>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="105"/>
         <source>Add Image</source>
         <translation>Ajouter une image</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="109"/>
-        <location filename="../src/new_game_tab.cpp" line="290"/>
         <source>Remove Image</source>
         <translation>Supprimer l&apos;image</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="113"/>
         <source>Image Properties</source>
         <translation>Propriétés de l&apos;image</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="132"/>
-        <location filename="../src/new_game_tab.cpp" line="383"/>
         <source>%L1 pieces</source>
         <translation>%L1 pièces</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="193"/>
         <source>Copying images...</source>
         <translation>Copie des images…</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="193"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../src/new_game_tab.cpp" line="286"/>
-        <source>Remove selected image?</source>
-        <translation>Supprimer l&apos;image sélectionnée ?</translation>
-    </message>
-    <message>
-        <location filename="../src/new_game_tab.cpp" line="288"/>
-        <source>Remove selected image?
-
-There are saved games using this image that will also be removed.</source>
-        <translation>Supprimer l&apos;image sélectionnée ?
-
-Les parties utilisant cette image seront également supprimées.</translation>
-    </message>
-    <message>
-        <location filename="../src/new_game_tab.cpp" line="493"/>
         <source>Untitled</source>
         <translation>Sans titre</translation>
     </message>
+    <message numerus="yes">
+        <source>Remove %n selected image(s)?</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Saved games using these image(s) will be deleted.</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>OpenGameTab</name>
     <message>
-        <location filename="../src/open_game_tab.cpp" line="86"/>
         <source>Untitled</source>
         <translation>Sans titre</translation>
     </message>
     <message>
-        <location filename="../src/open_game_tab.cpp" line="89"/>
         <source>%L1 pieces %2 %3% complete</source>
         <translation>%L1 pièces %2 %3% terminées</translation>
     </message>
     <message>
-        <location filename="../src/open_game_tab.cpp" line="105"/>
         <source>Delete</source>
         <translation>Supprimer</translation>
     </message>
     <message>
-        <location filename="../src/open_game_tab.cpp" line="148"/>
         <source>Delete Game</source>
         <translation>Supprimer la partie</translation>
     </message>
     <message>
-        <location filename="../src/open_game_tab.cpp" line="148"/>
         <source>Delete selected game?</source>
         <translation>Supprimer la partie sélectionnée ?</translation>
     </message>
@@ -280,7 +242,6 @@ Les parties utilisant cette image seront également supprimées.</translation>
 <context>
     <name>Overview</name>
     <message>
-        <location filename="../src/overview.cpp" line="38"/>
         <source>Overview</source>
         <translation>Vue d&apos;ensemble</translation>
     </message>
@@ -288,278 +249,233 @@ Les parties utilisant cette image seront également supprimées.</translation>
 <context>
     <name>TagManager</name>
     <message>
-        <location filename="../src/tag_manager.cpp" line="50"/>
         <source>Add Tag</source>
         <translation>Ajouter un mot-clef</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="54"/>
         <source>Remove Tag</source>
         <translation>Supprimer le mot-clef</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="59"/>
         <source>Untagged</source>
         <translation>Mot-clef retiré</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="88"/>
         <source>All Images</source>
         <translation>Toutes les images</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="208"/>
         <source>Untitled %1</source>
         <translation>Sans titre %1</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="232"/>
         <source>Question</source>
         <translation>Question</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="232"/>
         <source>Remove selected tag?</source>
         <translation>Supprimer le mot-clef sélectionné ?</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="273"/>
         <source>Sorry</source>
         <translation>Désolé</translation>
     </message>
     <message>
-        <location filename="../src/tag_manager.cpp" line="273"/>
         <source>A tag with that name already exists.</source>
         <translation>Un mot-clef identique existe déjà.</translation>
     </message>
+    <message>
+        <source>Manage Tags...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/main.cpp" line="147"/>
-        <location filename="../src/window.cpp" line="50"/>
-        <location filename="../src/window.cpp" line="286"/>
         <source>Tetzle</source>
         <translation>Tetzle</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="80"/>
         <source>&amp;Game</source>
         <translation>&amp;Jeu</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="84"/>
         <source>&amp;Retrieve Pieces</source>
         <translation>&amp;Piocher des pièces</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="84"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="88"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="81"/>
         <source>&amp;Choose...</source>
         <translation>&amp;Choisir…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="91"/>
         <source>&amp;View</source>
         <translation>&amp;Afficher</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="92"/>
         <source>Zoom &amp;In</source>
         <translation>Zoom &amp;avant</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="92"/>
         <source>+</source>
         <translation>+</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="95"/>
         <source>Zoom &amp;Out</source>
         <translation>Zoom &amp;arrière</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="95"/>
         <source>-</source>
         <translation>-</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="98"/>
         <source>Best &amp;Fit</source>
         <translation>&amp;Mise au point optimale</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="101"/>
         <source>Show O&amp;verview</source>
         <translation>Afficher la &amp;vue d&apos;ensemble</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="101"/>
         <source>Tab</source>
         <translation>Tab</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="107"/>
         <source>F&amp;ullscreen</source>
         <translation>&amp;Plein écran</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="111"/>
         <source>F11</source>
         <translation>F11</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="113"/>
         <source>Ctrl+F</source>
         <translation>Ctrl+F</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="116"/>
         <source>&amp;Settings</source>
         <translation>&amp;Paramètres</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="117"/>
         <source>&amp;Appearance...</source>
         <translation>&amp;Apparence…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="118"/>
         <source>&amp;Language...</source>
         <translation>&amp;Langue…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="120"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="121"/>
         <source>&amp;Controls</source>
         <translation>&amp;Commandes</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="123"/>
         <source>&amp;About</source>
         <translation>À &amp;propos de…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="125"/>
         <source>About &amp;Qt</source>
         <translation>À propos de &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="252"/>
         <source>Controls</source>
         <translation>Contrôles</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="259"/>
         <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Ramasser des pièces :&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="260"/>
-        <location filename="../src/window.cpp" line="262"/>
         <source>Left Click or Space</source>
         <translation>Clic gauche ou Barre d&apos;espace</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="261"/>
         <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Relâcher des pièces :&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="263"/>
         <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Sélectionner des pièces :&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="264"/>
         <source>Left Drag</source>
         <translation>Faire glisser à gauche</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="265"/>
         <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Rotation des pièces :&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="266"/>
         <source>Right Click, Control + Left Click, or R</source>
         <translation>Clic droit, Contrôle + Clic gauche, ou R</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="267"/>
         <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Faire glisser le puzzle :&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="268"/>
         <source>Middle Click, Shift + Left Click, or Arrows</source>
         <translation>Clic du milieu, Maj + Clic gauche, ou flèches</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="269"/>
         <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Zoomer sur le puzzle :&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="270"/>
         <source>Scrollwheel or +/-</source>
         <translation>Molette ou + / -</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="271"/>
         <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
         <translation>&lt;b&gt;Curseur de la souris :&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="272"/>
         <source>Move mouse or W,A,D,S</source>
         <translation>Déplacez la souris ou utilisez W,A,D,S</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="285"/>
         <source>About Tetzle</source>
         <translation>À propos de Tetzle</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="287"/>
         <source>A jigsaw puzzle with tetrominoes for pieces</source>
         <translation>Un puzzle Jigsaw à base de tétraminos</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="288"/>
         <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="289"/>
         <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
     </message>
+    <message>
+        <source>%p% complete</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ZoomSlider</name>
     <message>
-        <location filename="../src/zoom_slider.cpp" line="38"/>
-        <source>??%</source>
-        <translation>??%</translation>
+        <source>Zoom: %1%</source>
+        <translation type="unfinished"></translation>
     </message>
+</context>
+<context>
+    <name>main</name>
     <message>
-        <location filename="../src/zoom_slider.cpp" line="63"/>
-        <source>%1%</source>
-        <translation>%1%</translation>
+        <source>Images to add to the choose game dialog.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
